========================
Team and repository tags
========================

.. image:: https://governance.openstack.org/tc/badges/oslo.policy.svg
    :target: https://governance.openstack.org/tc/reference/tags/index.html

.. Change things from this point on

=============
 oslo.policy
=============

.. image:: https://img.shields.io/pypi/v/oslo.policy.svg
    :target: https://pypi.org/project/oslo.policy/
    :alt: Latest Version

The Oslo Policy library provides support for RBAC policy enforcement across
all OpenStack services.

* Free software: Apache license
* Documentation: https://docs.openstack.org/oslo.policy/latest/
* Source: https://git.openstack.org/cgit/openstack/oslo.policy
* Bugs: https://bugs.launchpad.net/oslo.policy
* Blueprints: https://blueprints.launchpad.net/oslo.policy
* Release Notes: https://docs.openstack.org/releasenotes/oslo.policy
